#ifndef bt_design_H
#define bt_design_H
#include <QPushButton>

class bt_design : public QPushButton
{
	Q_OBJECT
	public:
		bt_design(QWidget * parent);
		QFont myfont;
		int isover;
	public:
	private:
	signals:

	public slots:
	protected:
		void enterEvent(QEvent *);
		void leaveEvent(QEvent *);  
		void paintEvent(QPaintEvent *);
};
#endif
