#include <QtGui>
#include "helpfrm.h"

helpfrm::helpfrm(QWidget *parent) : QDialog(parent)
{
	setupUi(this);
	//QWidget::setWindowFlags(Qt::WindowMinMaxButtonsHint);
	//sed -i 1i'<meta http-equiv="content-type" content="text/html; charset=utf-8" />' *.html
	if ( QLocale::system().name().left(2) != "fr" )
	{
		QString wl_url = "http://translate.google.fr/translate?u=http://download.tuxfamily.org/2mandvd/help/index.html&sl=fr&tl=en&hl=fr&ie=UTF-8";

		webhelp->load(QUrl(wl_url));
	}
	else
	{
		webhelp->load(QUrl("http://download.tuxfamily.org/2mandvd/help/index.html"));
	}
}

