#ifndef simple_bt_H
#define simple_bt_H
#include <QPushButton>

class simple_bt : public QPushButton
{
	Q_OBJECT
	public:
		simple_bt(QWidget * parent);
		QPixmap pixbt; // *** ICONE NORMALE ***
		QPixmap pixbu; // *** ICONE SURVOLEE ***
		int isover;
		int hasback;
		QPixmap wl_fond;
	public:
	private:
	signals:

	public slots:
	protected:
		void enterEvent(QEvent *);
		void leaveEvent(QEvent *);  
		void paintEvent(QPaintEvent *);
};
#endif
