#ifndef MYLSTFILES_H
#define MYLSTFILES_H
#include <QListWidget>

class mylstfiles : public QListWidget
{
	Q_OBJECT
	public:
		mylstfiles(QWidget * parent);
	public:
		QPixmap currentselect;
		int currentselectindex;
		QString current_path;
		QString current_filename;
	private slots:
	signals:
		void media_chdir();
		void media_dble_import();
	private:
	protected:
		void mouseMoveEvent(QMouseEvent *);
		void mouseDoubleClickEvent(QMouseEvent *);
		Qt::DropActions supportedDropActions () const;
};
#endif

