#ifndef PANELMEDIA_H
#define PANELMEDIA_H
#include <QFrame>

class panelmedia : public QFrame
{
	Q_OBJECT
	public:
		panelmedia(QWidget * parent);
		QWidget *myparent;
		QString wl_pathname;
		int drop_x;
		int drop_y;
		QPixmap wg_pix_001;
		int islocked;

		QAction *action_load;

	public slots:
		void f_load_media();
	private:

	signals:
		void load_media();
		void drop_to_panel();
	protected:
		void contextMenuEvent(QContextMenuEvent*);
		void dropEvent(QDropEvent*);
		void dragEnterEvent(QDragEnterEvent*);
		void paintEvent(QPaintEvent*);
		Qt::DropActions supportedDropActions () const;
};
#endif
