#ifndef menu_editor_H
#define menu_editor_H
#include <QLabel>

class menu_editor : public QLabel
{
	Q_OBJECT
	public:
		menu_editor(QWidget * parent);

		int is_copy;
		int has_sound;
		int has_intro;
		int xevent;
		int yevent;


		QAction *action_customize;
		QAction *action_addone;
		QAction *action_addmul;
		QAction *action_intro_load;
		QAction *action_intro_cancel;
		QAction *action_paste;
		QAction *action_zik_load;
		QAction *action_zik_cancel;
		QAction *action_intro_calc;
		QAction *action_color_overlays;
	public:
	private:
	signals:
		void customize_background();
		void addone();
		void addmul();
		void loadintro();
		void cancelintro();
		void loadzik();
		void cancelzik();
		void paste_menu();
		void intro_calc();
		void color_overlays();
	public slots:
		void customize();
		void f_addone();
		void f_addmul();
		void f_load_intro();
		void f_cancel_intro();
		void f_load_zik();
		void f_cancel_zik();
		void f_paste();
		void f_calc();
		void f_coverl();
	protected:
		void contextMenuEvent(QContextMenuEvent *);
};
#endif
