#ifndef MYDIALY_H
#define MYDIALY_H
#include <QDial>

class mydialy : public QDial
{
	Q_OBJECT
	public:
		mydialy(QWidget * parent);
	public:
		int longueur;
	private:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
