#ifndef back_syno_H
#define back_syno_H
#include <QFrame>
#include "item_menu.h"
#include "item_media.h"

class back_syno : public QFrame
{
	Q_OBJECT
	public:
		back_syno(QWidget *);

		QString tab_rel[32][32];
		QString tab_rel_media[32][32];
		int nbre_menus;
		int num_actif;

		int wg_int_001;
		int wg_int_002;

		item_menu *tab_pnt_item[32];
		item_media *tab_pnt_media[60];
	public:

	private:
	signals:

	public slots:

	protected:
		void paintEvent(QPaintEvent *);
};
#endif
