#ifndef regles_H
#define regles_H
#include <QLabel>
#include <QListWidget>

class regles : public QLabel
{
	Q_OBJECT
	public:
		regles(QWidget * parent);
	public:
		int wgwidth;
		int wgheight;
	private:
		QPoint dragPosition;
	signals:

	public slots:

	protected:
		void paintEvent(QPaintEvent *);
		void mousePressEvent(QMouseEvent *);
		void mouseMoveEvent(QMouseEvent *);
		void mouseReleaseEvent(QMouseEvent *);
};
#endif
