#ifndef toolbar_bt_H
#define toolbar_bt_H
#include <QPushButton>

class toolbar_bt : public QPushButton
{
	Q_OBJECT
	public:
		toolbar_bt(QWidget * parent);
	public:
		int isover;
		int largeur;
		int hauteur;
	private:
	signals:

	public slots:
	protected:
		void enterEvent(QEvent *);
		void leaveEvent(QEvent *);  
		void paintEvent(QPaintEvent *);
};
#endif
