#ifndef frame_info_H
#define frame_info_H
#include <QFrame>

class frame_info : public QFrame
{
	Q_OBJECT
	public:
		frame_info(QWidget * parent);
	public:
		QString wl_action;
		QString wl_playlist;
		int wl_row_playlist;
		QFont myfont;
	private:
	signals:

	public slots:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
