/* ============================================================
 * File  : editor_txt.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include <QtGui>
#include "editor_txt.h"

editor_txt::editor_txt ( QWidget * parent )
    : QPlainTextEdit(parent)
{
	this->setAttribute(Qt::WA_DeleteOnClose);
}

void editor_txt::keyReleaseEvent( QKeyEvent *k )
{
    	if ( k->key() == Qt::Key_Shift )
    	{
		emit sh_unp();
    	}
}

void editor_txt::mousePressEvent(QMouseEvent *)
{
	emit enter_editor_txt();
}

/*void editor_txt::enterEvent ( QEvent * ) 
{
	emit enter_editor_txt();
}*/

