/****************************************************************************
** Meta object code from reading C++ file 'colorviewer.h'
**
** Created
**      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "widgets/colorviewer.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'colorviewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 59
#error "This file was generated using the moc from 4.4.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_ColorViewer[] = {

 // content:
       1,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   10, // methods
       0,    0, // properties
       0,    0, // enums/sets

 // slots: signature, parameters, type, tag, flags
      19,   13,   12,   12, 0x0a,

       0        // eod
};

static const char qt_meta_stringdata_ColorViewer[] = {
    "ColorViewer\0\0color\0changeColor(QColor)\0"
};

const QMetaObject ColorViewer::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ColorViewer,
      qt_meta_data_ColorViewer, 0 }
};

const QMetaObject *ColorViewer::metaObject() const
{
    return &staticMetaObject;
}

void *ColorViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_ColorViewer))
        return static_cast<void*>(const_cast< ColorViewer*>(this));
    return QWidget::qt_metacast(_clname);
}

int ColorViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: changeColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        }
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
