#ifndef HELPFRM_H
#define HELPFRM_H

#include <QDialog>
#include "ui_helpfrm.h"

class helpfrm : public QDialog, public Ui::helpfrm
{
	Q_OBJECT
	public:
		helpfrm(QWidget *parent = 0);
	private slots:


	private:
};
#endif
