#ifndef menu_th_H
#define menu_th_H
#include <QLabel>

class menu_th : public QLabel
{
	Q_OBJECT
	public:
		menu_th(QWidget * parent);
		int is_first;
		int is_edit;
		QPixmap draw_image;

		QAction *action_supprimer;
	public:
	private:
	signals:
		void select_menuth(menu_th*);
		void delete_menu(menu_th*);
	public slots:
		void supprimer();
	protected:
		void contextMenuEvent(QContextMenuEvent *);
		void mousePressEvent(QMouseEvent *);
		void paintEvent(QPaintEvent *);
};
#endif
