#ifndef myfileopen_H
#define myfileopen_H
#include <QFileDialog>

class myfileopen : public QFileDialog
{
	Q_OBJECT
	public:
		myfileopen(QWidget * parent);
		int source;
	public:
	private:
	signals:
		void change_image(QString);
		void f_close();
	public slots:
		void myfilesSelected( const QString );
	protected:
		virtual void closeEvent(QCloseEvent *)
		{
			emit f_close();
			//this->closeEvent(e);
		}
};
#endif
