/* ============================================================
 * File  : myfileopen.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include <QtGui>
#include "myfileopen.h"

myfileopen::myfileopen ( QWidget * parent )
    : QFileDialog(parent)
{
	setWindowTitle("2ManDVD");
	connect(this, SIGNAL(currentChanged(const QString)),this, SLOT(myfilesSelected(const QString)));
}

void myfileopen::myfilesSelected( QString lstselect )
{
	emit change_image(lstselect);
}
