#ifndef frame_bk_lm_lm_H
#define frame_bk_lm_lm_H
#include <QFrame>

class frame_bk_lm : public QFrame
{
	Q_OBJECT
	public:
		frame_bk_lm(QWidget * parent);
	public:
	private:
	signals:
	public slots:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
