#ifndef FRAME_CHAPTERS_H
#define FRAME_CHAPTERS_H
#include <QListWidget>

class frame_chapters : public QListWidget
{
	Q_OBJECT
	public:
		frame_chapters(QWidget * parent);
	public:
		QAction *action_delete;
	signals:
		void gochapter(QString);
		void delete_row(QString);
	public slots:
		void delete_chapitres();
		void f_delete_row(QString);
	private:
		void mouseDoubleClickEvent(QMouseEvent *);
	protected:
		void contextMenuEvent(QContextMenuEvent *event);
};
#endif
