#ifndef THPTRA_H
#define THPTRA_H
 
#include <QtGui>
 
class thptra : public QThread
{
	Q_OBJECT
 
public:
	thptra();
	int sequence;
	int x,y;
	int type_trans;
	float lumavalue;
	int valuefade;

	QColor tmpcolor1;
	QColor tmpcolor2;
	QColor tmpcolor3;
	QColor mycolor;
	QColor mycolor2;

	QRgb srcPixel;
	QRgb srcPixel2;
	QRgb srcPixel3;
	QRgb dstPixel;

	QImage srcImage;
	QImage srcImage2;
	QImage srcImage3;
	QImage dstImage;

	QString invert;

	void run();
	void finished();

	signals:
	void myfin(); 
};
 
 
#endif
