#include <QApplication>
#include "mainfrm.h"
#include <QCleanlooksStyle>

int main(int argc, char *argv[])
{
	QApplication::setStyle(new QCleanlooksStyle);
	QApplication app(argc, argv);
	mainfrm *dialog = new mainfrm;
	dialog->show();
	return app.exec();
}
