#ifndef slider_H
#define slider_H
#include <QSlider>

class slider : public QSlider
{
	Q_OBJECT
	public:
		slider(QWidget * parent);
	public:
	signals:
	private:
	protected:
		void wheelEvent ( QWheelEvent * );
};
#endif
