#ifndef item_media_H
#define item_media_H
#include <QLabel>
#include "media.h"

class item_media : public QLabel
{
	Q_OBJECT
	public:
		item_media(QWidget *);

		QPixmap fond;
		int nbre_menus;
		int num_menu;
		QAction *action_reencode;
		media *hdlmedia;

	public:

	private:
		QPoint dragPosition;
	signals:
		void item_move(item_media*);
		void affiche_info(item_media*);
		void hide_info(item_media*);
		void sg_ren_media(media*);
	public slots:
		void ren_media();
	protected:
		void contextMenuEvent(QContextMenuEvent *);
		void paintEvent(QPaintEvent *);
		void mousePressEvent(QMouseEvent *);
		void mouseMoveEvent(QMouseEvent *);
		void mouseReleaseEvent(QMouseEvent *);
		void enterEvent(QEvent *);
		void leaveEvent(QEvent *);
};
#endif
