#ifndef item_menu_H
#define item_menu_H
#include <QLabel>

class item_menu : public QLabel
{
	Q_OBJECT
	public:
		item_menu(QWidget *);

		QPixmap fond;
		int nbre_menus;
		int nbre_medias;
		int num_menu;
		QString table_medias[60];
		QString wg_str_001;
		QAction *action_editmenu;

	public:

	private:
		QPoint dragPosition;
	signals:
		void item_move(item_menu*);
		void item_select(item_menu*);
		void affiche_info(item_menu*);
		void hide_info(item_menu*);
		void add_link(item_menu*,int);
		void add_link_media(item_menu*,QString);
		void edit_menu_tree(item_menu*);
	public slots:
		void f_link();
		void f_link_media();
		void f_edit();
	protected:
		void contextMenuEvent(QContextMenuEvent *);
		void paintEvent(QPaintEvent *);
		void mousePressEvent(QMouseEvent *);
		void mouseMoveEvent(QMouseEvent *);
		void mouseReleaseEvent(QMouseEvent *);
		void enterEvent(QEvent *);
		void leaveEvent(QEvent *);
};
#endif
