#ifndef safety_H
#define safety_H
#include <QLabel>

class safety : public QLabel
{
	Q_OBJECT
	public:
		safety(QWidget * parent);
	public:
	private:
	signals:

	public slots:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
