#ifndef theme_navigator_H
#define theme_navigator_H
#include <QListWidget>
#include "menu.h"

class theme_navigator : public QListWidget
{
	Q_OBJECT
	public:
		theme_navigator(QWidget * parent);

		QString wg_string_001;
		QString wg_string_002;

		int wg_int_001;
		int wg_int_002;

		QString pathname;
		QString top_pathname;

		QPixmap wg_pix_001;
	public:
		void f_load_theme();
	private:
	signals:

	public slots:
	protected:
};
#endif
