#ifndef standard_list_H
#define standard_list_H
#include <QListWidget>

class standard_list : public QListWidget
{
	Q_OBJECT
	public:
		standard_list(QWidget * parent);
	public:
		QAction *action_delete;
	signals:
		void delete_row(int);
	public slots:
		void delete_select();
		//void f_delete_row(QString);
	private:
	protected:
		void contextMenuEvent(QContextMenuEvent *event);
};
#endif
