#ifndef THANI_H
#define THANI_H
 
#include <QtGui>
 
class thani : public QThread
{
	Q_OBJECT
 
public:
	thani();
	QLabel *hdlmsk;
	int sens;
	int progress;
	int isrender;
	QPixmap pix_001;

	void run();
	void finished();

	signals:
		void finanim();
		void fincache();
		void lockbar();
	private slots:
	void boucle();

};
 
 
#endif

