#ifndef top_bar_H
#define top_bar_H
#include <QFrame>

class top_bar : public QFrame
{
	Q_OBJECT
	public:
		top_bar(QWidget * parent);
	public:
		QPoint dragPosition;
	private:
	signals:

	public slots:
		
	protected:
		void mouseMoveEvent(QMouseEvent*);
		void mousePressEvent(QMouseEvent*);
		void mouseReleaseEvent(QMouseEvent*);
		void paintEvent(QPaintEvent*);
};
#endif
