#ifndef THIMG_H
#define THIMG_H
 
#include <QtGui>
 
class thimg : public QThread
{
	Q_OBJECT
 
public:
	thimg();
	int lumi;
	int cont;
	int rouge;
	int vert;
	int bleu;
	int valueadd_R;
	int valueadd_V;
	int valueadd_B;
	int opacity;
	QRgb srcPixel;
	QColor trtcolor;
	QImage wlimg;
	int c_r;
	int c_v;
	int c_b;
	int ac_r;
	int ac_v;
	int ac_b;
	void run();
	void finished();
	signals:
	void myfin(); 
};
 
 
#endif
