/* ============================================================
 * File  : tetrahedron.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include <QtGui>
#include "timeline.h"

timeline::timeline ( QWidget * parent )
    : QFrame(parent)
{
	this->setMouseTracking(false);
	//this->setAttribute(Qt::WA_DeleteOnClose);
}

// ********************************
// *** DESSIN DU FOND DU WIDGET ***
// ********************************

void timeline::paintEvent(QPaintEvent *)
{
	/*QPainter p;
	p.begin(this);
	p.setPen(Qt::NoPen);
	p.setRenderHint(QPainter::Antialiasing,true);
	p.drawRect(0, 0, this->width(), this->height());
	p.setBrush(QColor(20,20,20,255));
	p.drawRect(1, 1, this->width()-2, this->height()-2);
	p.end();*/
}

