#ifndef fixback_H
#define fixback_H
#include <QFrame>

class fixback : public QFrame
{
	Q_OBJECT
	public:
		fixback(QWidget * parent);
		QPixmap fond_application;
	public:
	signals:
	private:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
