#ifndef editor_txt_H
#define editor_txt_H
#include <QPlainTextEdit>

class editor_txt : public QPlainTextEdit
{
	Q_OBJECT
	public:
		editor_txt(QWidget * parent);
	public:
	private:
	signals:
		void sh_unp();
		void enter_editor_txt();
	public slots:
	protected:
		//void enterEvent( QEvent * );
		void mousePressEvent(QMouseEvent *);
		void keyReleaseEvent( QKeyEvent * );
};
#endif
