#ifndef designer_H
#define designer_H
#include <QFrame>

class designer : public QFrame
{
	Q_OBJECT
	public:
		designer(QWidget * parent);
		QImage draw_user;
		int mouse_x;
		int mouse_y;

		int old_mouse_x;
		int old_mouse_y;

		int brush_width;

		int tool;

		int is_in;
		int is_modification;

		int is_draw_ct;
		int draw_ct_x;
		int draw_ct_y;
	public:
	signals:
	private:
		QPoint dragPosition;
	protected:
		void enterEvent(QEvent *);
		void leaveEvent(QEvent *);
		void mouseMoveEvent(QMouseEvent*);
		void mousePressEvent(QMouseEvent*);
		void mouseReleaseEvent(QMouseEvent*);
		void paintEvent(QPaintEvent *);
};
#endif
