#ifndef flag_H
#define flag_H
#include <QLabel>
#include "menu.h"

class flag : public QLabel
{
	Q_OBJECT
	public:
		flag(QWidget * parent);
	public:
		QFont myfont;
		int position;
		int maximum;
		menu *hdlmenu;
	private:
	signals:
		void change_pos();

	public slots:
	protected:
		void wheelEvent(QWheelEvent *);
		void paintEvent(QPaintEvent *);
};
#endif
