#ifndef thmenu_H
#define thmenu_H
 
#include <QtGui>
 
class thmenu : public QThread
{
	Q_OBJECT
 
public:
	thmenu();
	public:

	QWidget *w1;
	QWidget *w2;

	int wy;
	QString sens;

	public slots:
	void boucle();

	void run();

	signals:

	private slots:

};
 
 
#endif

