#ifndef thblend_H
#define thblend_H
 
#include <QtGui>
 
class thblend : public QThread
{
	Q_OBJECT
 
public:
	thblend();

	QImage srcImage;
	QImage srcImage2;
	QImage dstImage;

	QColor tmpcolor1;
	QColor tmpcolor2;
	QColor tmpcolor3;

	QRgb srcPixel;
	QRgb srcPixel2;

	int sequence;

	void run();
	void finished();

	signals:
	void stepend();
	void endblend();
	private slots:

};
 
 
#endif

