#ifndef property_H
#define property_H
#include <QFrame>

class property : public QFrame
{
	Q_OBJECT
	public:
		property(QWidget * parent);
		QFont myfont;
	public:
	signals:
	private:
		QPoint dragPosition;
	protected:
		void mouseMoveEvent(QMouseEvent*);
		void mousePressEvent(QMouseEvent*);
		void mouseReleaseEvent(QMouseEvent*);
		void paintEvent(QPaintEvent *);
};
#endif
