#ifndef timeline_H
#define timeline_H
#include <QFrame>

class timeline : public QFrame
{
	Q_OBJECT
	public:
		timeline(QWidget * parent);
	public:
	private:
	signals:

	public slots:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
