#ifndef frame_tooltip_H
#define frame_tooltip_H
#include <QFrame>

class frame_tooltip : public QFrame
{
	Q_OBJECT
	public:
		frame_tooltip(QWidget * parent);
	public:
		QString wl_pathname_media;
		QString wl_width;
		QString wl_height;
		QString wl_fps;
		QString wl_duree;
		QString wl_format;
		QString wl_audio_channel;
		int wl_isdvd;
		QString wl_chapitres;
		QFont myfont;
	private:
	signals:

	public slots:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
