#ifndef frame_bk_H
#define frame_bk_H
#include <QFrame>

class frame_bk : public QFrame
{
	Q_OBJECT
	public:
		frame_bk(QWidget * parent);
	public:
	private:
		//QPoint dragPosition;
		QFont myfont;
	signals:
		void show_frame_bk();
		void hide_frame_bk();
	public slots:
	protected:
		void mouseMoveEvent(QMouseEvent *event);
		//void mousePressEvent ( QMouseEvent * event );
		void paintEvent(QPaintEvent *);
		//void enterEvent(QEvent *);
		void leaveEvent(QEvent *);
};
#endif
