#ifndef is_is_H
#define is_is_H
#include <QLabel>

class is_is : public QLabel
{
	Q_OBJECT
	public:
		is_is(QWidget * parent);
	public:
		int is_active;
	private:
	signals:

	public slots:
	protected:
		void paintEvent(QPaintEvent *);
};
#endif
